@@ -179,6 +179,11 @@ class NodeList(NodeMixIn, base.BaseListCommand):
                'platform_name',
                'online')
 
+    filters = {
+        'environment_id': 'env',
+        'labels': 'labels'
+    }
+
     def get_parser(self, prog_name):
         parser = super(NodeList, self).get_parser(prog_name)
 
@@ -197,13 +202,6 @@ class NodeList(NodeMixIn, base.BaseListCommand):
 
         return parser
 
-    def take_action(self, parsed_args):
-        data = self.client.get_all(
-            environment_id=parsed_args.env, labels=parsed_args.labels)
-        data = data_utils.get_display_data_multi(self.columns, data)
-
-        return (self.columns, data)
-
 
 class NodeShow(NodeMixIn, base.BaseShowCommand):
     """Show info about node with given id."""
@@ -328,6 +326,10 @@ class NodeLabelList(NodeMixIn, base.BaseListCommand):
         'label_name',
         'label_value')
 
+    @property
+    def default_sorting_by(self):
+        return ['node_id']
+
     def get_parser(self, prog_name):
         parser = super(NodeLabelList, self).get_parser(prog_name)
 
@@ -343,8 +345,9 @@ class NodeLabelList(NodeMixIn, base.BaseListCommand):
         data = self.client.get_all_labels_for_nodes(
             node_ids=parsed_args.nodes)
         data = data_utils.get_display_data_multi(self.columns, data)
+        data = self._sort_data(parsed_args, data)
 
-        return (self.columns, data)
+        return self.columns, data
 
 
 class NodeLabelSet(NodeMixIn, base.BaseCommand):
